@@ -31,5 +31,8 @@ extern void progress_init(struct progress_bar *p, int start, int stop, int res,
 
 /// update number
 extern void progress_update(struct progress_bar *p, int current, int done);
+extern void Ncurses_progress_update(struct progress_bar *p, int current, int done);
 
-
+static open_p_ncurses();
+static close_p_ncurses();
+extern void Dialog_progress_update(struct progress_bar *p, int current, int done);
